package com.artemisbookstore.csv;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;

/**
 * This program generates a text file from the ArtemisBookstore CSV data
 * stored in data/artemisBookstoreData-v1.csv. The generated turtle data
 * is stored in data/generated/artemisBookstoreData-v1.txt
 *
 * @author Philippe Genoud - LIG Steamer - Université Grenoble Alpes
 */
public class GenerateBookStoreText {

    /**
     *
     * @param csvFileName    name of the input CSV file
     * @param textFilName name of the output text file
     *
     * @throws java.io.IOException
     */
    public static void generateTurtle(String csvFileName, String textFilName) throws IOException {

        try (BufferedReader br = Files.newBufferedReader(Paths.get(csvFileName));
                BufferedWriter bw = Files.newBufferedWriter(Paths.get(textFilName))) {
            // using Files.newBufferedReader and Files.newBufferedWriter enforce
            // charEncodingto UTF-8.
            // Files.newBufferedWriter(Paths.get(turtleFileName)) is equivalent to
            // BufferedWriter bw = new BufferedWriter(new OutputStreamWriter(new
            // FileOutputStream(turtleFileName), StandardCharsets.UTF_8));

            String line;
            br.readLine(); // to skip the column titles line
            while ((line = br.readLine()) != null) {
                // split the line in using the ';' (semicolon)
                String[] lineTokens = line.split(";");

                String authorFamilyName = lineTokens[0];
                String authorGivenName = lineTokens[1];
                String bookTitle = lineTokens[2];
                int pagesNb = Integer.parseInt(lineTokens[3]);
                String isbn = lineTokens[4];
                String publisherName = lineTokens[5];

                String outputLine = """
                        -------------------------------------------------------------------------------------------------------
                        Auteur [nom:%s, prénom:%s]
                        Editeur [nom: %s]
                        Livre [titre: %s, nbre pages: %d, isbn: %s]
                            """
                        .formatted(authorGivenName, authorFamilyName, publisherName, bookTitle, pagesNb, isbn);
                // System.out.println(outputLine);
                bw.write(outputLine);
            } // end of file
        }
    }

    public static void main(String[] args) throws IOException {
        try {
            generateTurtle("data/artemisBookstoreData-v1.csv", "data/generated/artemisBookstoreData-v1-en.txt");
            System.out.println("\nText data has been generated");
        } catch (IOException e) {
            System.out.println("I/O Error while Generating Text Data");
            e.printStackTrace();
        }
    }

}